---
name: Feature request
about: Suggest an idea for this project. If this doesn’t work right, [choose a different
  type]( https://github.com/deepmodeling/dpgen/issues/new/choose).
title: "[Feature Request] _Replace with Title_"
labels: new feature
assignees: ''

---

**Summary**

<!--Please provide a brief and concise description of the suggested feature or change-->

**Detailed Description**

<!--Please explain how you would like to see DPGEN enhanced, what feature(s) you are looking for, what specific problems this will solve. If possible, provide references to relevant background information like publications or web pages, and whether you are planning to implement the enhancement yourself or would like to participate in the implementation. If applicable add a reference to an existing bug report or issue that this will address.-->

**Further Information, Files, and Links**

<!--Put any additional information here, attach relevant text or image files and URLs to external sites, e.g. relevant publications-->
